summaryrefslogtreecommitdiffstats
path: root/lskat/lskat/namedlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lskat/lskat/namedlg.cpp')
-rw-r--r--lskat/lskat/namedlg.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/lskat/lskat/namedlg.cpp b/lskat/lskat/namedlg.cpp
index 4bbffad7..66296195 100644
--- a/lskat/lskat/namedlg.cpp
+++ b/lskat/lskat/namedlg.cpp
@@ -19,15 +19,15 @@
#define NAME_MAX_LEN 12
/*
* Constructs a NameDlg which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-NameDlg::NameDlg( TQWidget *parent, const char *name,bool /* modal */, WFlags /* fl */ )
+NameDlg::NameDlg( TQWidget *tqparent, const char *name,bool /* modal */, WFlags /* fl */ )
: KDialogBase( Plain, i18n("Configure Names"), Ok|Cancel, Ok,
- parent, name, true,true )
+ tqparent, name, true,true )
{
TQWidget *page = plainPage();
@@ -45,10 +45,10 @@ NameDlg::NameDlg( TQWidget *parent, const char *name,bool /* modal */, WFlags /*
player_names = new TQGroupBox( page, "player_names" );
player_names->setTitle(i18n("Player Names") );
player_names->setColumnLayout(0, Qt::Vertical );
- player_names->layout()->setSpacing( 0 );
- player_names->layout()->setMargin( 0 );
- vbox_2 = new TQVBoxLayout( player_names->layout() );
- vbox_2->setAlignment( Qt::AlignTop );
+ player_names->tqlayout()->setSpacing( 0 );
+ player_names->tqlayout()->setMargin( 0 );
+ vbox_2 = new TQVBoxLayout( player_names->tqlayout() );
+ vbox_2->tqsetAlignment( TQt::AlignTop );
vbox_2->setSpacing( 6 );
vbox_2->setMargin( 11 );
@@ -109,7 +109,7 @@ NameDlg::NameDlg( TQWidget *parent, const char *name,bool /* modal */, WFlags /*
*/
NameDlg::~NameDlg()
{
// no need to delete child widgets, Qt does it all for us
}
// In and output the name strings
@@ -19,15 +19,15 @@
#define NAME_MAX_LEN 12
/*
- * Constructs a NameDlg which is a child of 'parent', with the
+ * Constructs a NameDlg which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*
@@ -109,7 +109,7 @@ NameDlg::NameDlg( TQWidget *parent, const char *name,bool /* modal */, WFlags /*
NameDlg::~NameDlg()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
// In and output the name strings